==> phoenix_widgets-1.11.1.tar.gz: lib/phoenix_list_group.dart <==
import 'package:flutter/material.dart';

class PhoenixListGroup extends StatelessWidget {
  const PhoenixListGroup({
    Key? key,
    required this.groupList,
  }) : super(key: key);
  final Map<String, List<DataHelper>> groupList;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        /// Generate group menu title
        for (int rootIndex = 0; rootIndex < groupList.keys.length; rootIndex++)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.all(8),
                child: Text(
                  groupList.keys.elementAt(rootIndex),
                  style: const TextStyle(
                    color: Color(0xff75767A),
                    fontWeight: FontWeight.normal,
                    fontSize: 14,
                  ),
                ),
              ),

              /// Generate child in group menu
              for (final child in groupList.values.elementAt(rootIndex))
                if (child.isVisible)
                  Column(
                    children: [
                      TextButton(
                        style: TextButton.styleFrom(
                          padding: const EdgeInsets.symmetric(horizontal: 8),
                          primary: const Color(0xff67C1BF),
                        ),
                        onPressed: child.onPressed,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Text(
                              child.title ?? "",
                              style: const TextStyle(
                                color: Color(0xFF212124),
                                fontSize: 16,
                                fontWeight: FontWeight.normal,
                              ),
                            ),
                            const Icon(
                              Icons.chevron_right_rounded,
                              color: Color(0xff75767A),
                            ),
                          ],
                        ),
                      ),
                      const Divider(
                        color: Color(0xffD9DBE0),
                        thickness: 1,
                        height: 0,
                      )
                    ],
                  ),
              const SizedBox(height: 24),
            ],
          )
      ],
    );
  }
}

class DataHelper {
  final String? title;
  final String? desc;
  bool isSelected;
  final String? iconPath;
  final IconData? icon;
  final String? url;
  final String? type;
  final int? id;
  VoidCallback? onPressed;
  bool isVisible;
  final Color? color;

  DataHelper({
    this.title,
    this.desc,
    this.isSelected = false,
    this.iconPath,
    this.icon,
    this.url,
    this.type,
    this.id,
    this.onPressed,
    this.isVisible = true,
    this.color,
  });
}

==> phoenix_widgets-1.16.5.tar.gz: lib/phoenix_list_group.dart <==
import 'package:flutter/material.dart';

class PhoenixListGroup extends StatelessWidget {
  const PhoenixListGroup({
    Key? key,
    required this.groupList,
  }) : super(key: key);
  final Map<String, List<DataHelper>> groupList;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        /// Generate group menu title
        for (int rootIndex = 0; rootIndex < groupList.keys.length; rootIndex++)
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.all(8),
                child: Text(
                  groupList.keys.elementAt(rootIndex),
                  style: const TextStyle(
                    color: Color(0xff75767A),
                    fontWeight: FontWeight.normal,
                    fontSize: 14,
                  ),
                ),
              ),

              /// Generate child in group menu
              for (final child in groupList.values.elementAt(rootIndex))
                if (child.isVisible)
                  Column(
                    children: [
                      TextButton(
                        style: TextButton.styleFrom(
                          padding: const EdgeInsets.symmetric(horizontal: 8),
                          onSurface: const Color(0xff67C1BF),
                        ),
                        onPressed: child.onPressed,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Text(
                              child.title ?? "",
                              style: const TextStyle(
                                color: Color(0xFF212124),
                                fontSize: 16,
                                fontWeight: FontWeight.normal,
                              ),
                            ),
                            const Icon(
                              Icons.chevron_right_rounded,
                              color: Color(0xff75767A),
                            ),
                          ],
                        ),
                      ),
                      const Divider(
                        color: Color(0xffD9DBE0),
                        thickness: 1,
                        height: 0,
                      )
                    ],
                  ),
              const SizedBox(height: 24),
            ],
          )
      ],
    );
  }
}

class DataHelper {
  final String? title;
  final String? desc;
  bool isSelected;
  final String? iconPath;
  final IconData? icon;
  final String? url;
  final String? type;
  final int? id;
  VoidCallback? onPressed;
  bool isVisible;
  final Color? color;

  DataHelper({
    this.title,
    this.desc,
    this.isSelected = false,
    this.iconPath,
    this.icon,
    this.url,
    this.type,
    this.id,
    this.onPressed,
    this.isVisible = true,
    this.color,
  });
}
